==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/urls_etendues/lang/urls_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/urls?lang_cible=it
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'actualiser_toutes' => 'Aggiorna tutti gli url',
	'actualiser_toutes_explication' => 'Vous pouvez recalculer les URLs.
		Si une URL a changé, une nouvelle entrée sera créée (sans perdre les URLs déjà
		présentes et sans affecter les URLs définies manuellement.', # NEW

	// B
	'bouton_supprimer_url' => 'Cancella questo URL',

	// E
	'erreur_arbo_2_segments_max' => 'Non puoi usare più di due segmenti di URL per un\'oggetto',
	'erreur_config_url_forcee' => 'La configurazione degli URL è fissata nel file <tt>mes_options.php</tt>.',
	'explication_editer' => 'La gestione avanzata degli URL permette di moficare l\'URL delle pagine per ogni oggetto editoriale, e di mantenere lo storico delle loro evoluzioni.',

	// I
	'icone_configurer_urls' => 'Configurazione degli URL',
	'icone_controler_urls' => 'URL significative',
	'info_1_url' => '1 URL',
	'info_id_parent' => '#parent',
	'info_nb_urls' => '@nb@ URL',
	'info_objet' => 'Oggetto',

	// L
	'label_tri_date' => 'Data',
	'label_tri_id' => 'ID',
	'label_tri_url' => 'URL',
	'label_url' => 'Nuovo URL',
	'label_url_minuscules_0' => 'Conservare il maiuscolo/minuscolo dei caratteri',
	'label_url_minuscules_1' => 'Forza i caratteri minuscoli negli URL',
	'label_url_permanente' => 'Blocca questo URL (nessun aggiornamento dopo la modifica dell\'oggetto)',
	'label_url_sep_id' => 'Carattere di separazione dei numeri in caso di duplicati',
	'label_urls_activer_controle_oui' => 'Attivare la gestione avanzata degli URL',
	'label_urls_nb_max_car' => 'Massimo numero di caratteri',
	'label_urls_nb_min_car' => 'Minimo numero di caratteri',
	'liberer_url' => 'Versione',
	'liste_des_urls' => 'Tutti gli URL',

	// T
	'texte_type_urls' => 'È possibile scegliere qui sotto il modo di elaborazione dell\'indirizzo delle pagine.',
	'texte_type_urls_attention' => 'Attenzione: questa impostazione funziona solamente se il file @htaccess@ è installato correttamente alla radice del sito.',
	'texte_urls_nb_max_car' => 'Se il titolo è più lungo verrà tagliato',
	'texte_urls_nb_min_car' => 'Se il titolo è più corta, è il suo numero identificativo che verrà utilizzato.',
	'titre_gestion_des_urls' => 'Gestione degli URL',
	'titre_type_arbo' => 'Albero degli URL',
	'titre_type_html' => 'URL degli oggetti HTML',
	'titre_type_libres' => 'URL liberi',
	'titre_type_page' => 'URL delle pagine',
	'titre_type_propres' => 'URL puliti',
	'titre_type_propres2' => 'URL puliti+<tt>.html</tt>',
	'titre_type_propres_qs' => 'Pulizia della stringa di ricerca degli URL',
	'titre_type_simple' => 'URL Semplici',
	'titre_type_standard' => 'URL Storici',
	'titre_type_urls' => 'Tipo di indirizzi URL',
	'tout_voir' => 'Mostra tutti gli URL',

	// U
	'url_ajout_impossible' => 'C\'è stato un\'errore. L\'URL non è stato salvato.',
	'url_ajoutee' => 'L\'URL è stato aggiunto',

	// V
	'verifier_url_nettoyee' => 'L\'URL è stato corretto, puoi controllarlo prima di salvare.',
	'verrouiller_url' => 'Bloccato'
);

?>

==> spip_3.0.11.orig.tar.xz: spip-3.0.11.orig/plugins-dist/urls_etendues/lang/urls_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/urls?lang_cible=it
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'actualiser_toutes' => 'Aggiorna tutti gli url',
	'actualiser_toutes_explication' => 'Puoi riprocessare l\'URL. Se un URL è cambiato, una nuova voce viene creata (senza perdere l\'URL già presente e senza impatti sugli URL modificati manualmente).',

	// B
	'bouton_supprimer_url' => 'Cancella questo URL',

	// E
	'erreur_arbo_2_segments_max' => 'Non puoi usare più di due segmenti di URL per un\'oggetto',
	'erreur_config_url_forcee' => 'La configurazione degli URL è fissata nel file <tt>mes_options.php</tt>.',
	'explication_editer' => 'La gestione avanzata degli URL permette di moficare l\'URL delle pagine per ogni oggetto editoriale, e di mantenere lo storico delle loro evoluzioni.',

	// I
	'icone_configurer_urls' => 'Configurazione degli URL',
	'icone_controler_urls' => 'URL significative',
	'info_1_url' => '1 URL',
	'info_id_parent' => '#parent',
	'info_nb_urls' => '@nb@ URL',
	'info_objet' => 'Oggetto',

	// L
	'label_tri_date' => 'Data',
	'label_tri_id' => 'ID',
	'label_tri_url' => 'URL',
	'label_url' => 'Nuovo URL',
	'label_url_minuscules_0' => 'Conservare il maiuscolo/minuscolo dei caratteri',
	'label_url_minuscules_1' => 'Forza i caratteri minuscoli negli URL',
	'label_url_permanente' => 'Blocca questo URL (nessun aggiornamento dopo la modifica dell\'oggetto)',
	'label_url_sep_id' => 'Carattere di separazione dei numeri in caso di duplicati',
	'label_urls_activer_controle_oui' => 'Attivare la gestione avanzata degli URL',
	'label_urls_nb_max_car' => 'Massimo numero di caratteri',
	'label_urls_nb_min_car' => 'Minimo numero di caratteri',
	'liberer_url' => 'Versione',
	'liste_des_urls' => 'Tutti gli URL',

	// T
	'texte_type_urls' => 'È possibile scegliere qui sotto il modo di elaborazione dell\'indirizzo delle pagine.',
	'texte_type_urls_attention' => 'Attenzione: questa impostazione funziona solamente se il file @htaccess@ è installato correttamente alla radice del sito.',
	'texte_urls_nb_max_car' => 'Se il titolo è più lungo verrà tagliato',
	'texte_urls_nb_min_car' => 'Se il titolo è più corta, è il suo numero identificativo che verrà utilizzato.',
	'titre_gestion_des_urls' => 'Gestione degli URL',
	'titre_type_arbo' => 'Albero degli URL',
	'titre_type_html' => 'URL degli oggetti HTML',
	'titre_type_libres' => 'URL liberi',
	'titre_type_page' => 'URL delle pagine',
	'titre_type_propres' => 'URL puliti',
	'titre_type_propres2' => 'URL puliti+<tt>.html</tt>',
	'titre_type_propres_qs' => 'Pulizia della stringa di ricerca degli URL',
	'titre_type_simple' => 'URL Semplici',
	'titre_type_standard' => 'URL Storici',
	'titre_type_urls' => 'Tipo di indirizzi URL',
	'tout_voir' => 'Mostra tutti gli URL',

	// U
	'url_ajout_impossible' => 'C\'è stato un\'errore. L\'URL non è stato salvato.',
	'url_ajoutee' => 'L\'URL è stato aggiunto',

	// V
	'verifier_url_nettoyee' => 'L\'URL è stato corretto, puoi controllarlo prima di salvare.',
	'verrouiller_url' => 'Bloccato'
);

?>
